@@ -6,8 +6,12 @@
 
 //! `sysinfo` is a crate used to get a system's information.
 //!
-//! Before any attempt to read the different structs' information, you need to update them to
-//! get up-to-date information.
+//! /!\ Before any attempt to read the different structs' information, you need to update them to
+//! get up-to-date information because for most of them, it works on diff between the current value
+//! and the old one.
+//!
+//! Which is why, it's much better to keep the same instance of [`System`] around instead of
+//! recreating it multiple times.
 //!
 //! # Examples
 //!
@@ -70,6 +74,7 @@ macro_rules! sysinfo_debug {
 
 #[cfg(not(feature = "debug"))]
 #[doc(hidden)]
+#[allow(unused)]
 macro_rules! sysinfo_debug {
     ($($x:tt)*) => {{}};
 }
@@ -81,7 +86,7 @@ cfg_if::cfg_if! {
         extern crate core_foundation_sys;
 
         #[cfg(test)]
-        const MIN_USERS: usize = 1;
+        pub(crate) const MIN_USERS: usize = 1;
     } else if #[cfg(windows)] {
         mod windows;
         use windows as sys;
@@ -89,19 +94,19 @@ cfg_if::cfg_if! {
         extern crate ntapi;
 
         #[cfg(test)]
-        const MIN_USERS: usize = 1;
+        pub(crate) const MIN_USERS: usize = 1;
     } else if #[cfg(any(target_os = "linux", target_os = "android"))] {
         mod linux;
         use linux as sys;
 
         #[cfg(test)]
-        const MIN_USERS: usize = 1;
+        pub(crate) const MIN_USERS: usize = 1;
     } else {
         mod unknown;
         use unknown as sys;
 
         #[cfg(test)]
-        const MIN_USERS: usize = 0;
+        pub(crate) const MIN_USERS: usize = 0;
     }
 }
 
@@ -183,12 +188,15 @@ mod test {
         let mut s = System::new();
 
         s.refresh_all();
-        assert_eq!(
-            s.get_processes()
-                .iter()
-                .all(|(_, proc_)| proc_.memory() == 0),
-            false
-        );
+        // We don't want to test on unsupported systems.
+        if MIN_USERS > 0 {
+            assert_eq!(
+                s.get_processes()
+                    .iter()
+                    .all(|(_, proc_)| proc_.memory() == 0),
+                false
+            );
+        }
     }
 
     #[cfg(target_os = "linux")]
@@ -258,7 +266,7 @@ mod test {
 
     #[test]
     fn check_system_info() {
-        // We don't want to test on unknown systems.
+        // We don't want to test on unsupported systems.
         if MIN_USERS > 0 {
             let s = System::new();
             assert!(!s.get_name().expect("Failed to get system name").is_empty());
@@ -282,7 +290,7 @@ mod test {
 
     #[test]
     fn check_host_name() {
-        // We don't want to test on unknown systems.
+        // We don't want to test on unsupported systems.
         if MIN_USERS > 0 {
             let s = System::new();
             assert!(!s
@@ -294,7 +302,7 @@ mod test {
 
     #[test]
     fn check_refresh_process_return_value() {
-        // We don't want to test on unknown systems.
+        // We don't want to test on unsupported systems.
         if MIN_USERS > 0 {
             let pid = get_current_pid().expect("Failed to get current PID");
             let mut s = System::new();
